package org.aohe.core.web;

import lombok.Getter;
import lombok.extern.slf4j.Slf4j;

import java.net.BindException;
import java.net.UnknownHostException;

/**
 * Socket 工厂
 */
@Slf4j
public class SocketFactory {

    /**
     * -- GETTER --
     *  get 方法
     *
     * @return
     */
    @Getter
    private static SocketServer socketServer;

    private SocketFactory() {
    }


    /**
     * 获取Socket客户端
     * @return socketServer
     */
    private static SocketServer getSocket() throws UnknownHostException {
        log.info("Create Socket ...");
        socketServer = new SocketServer(8997);
        socketServer.setReuseAddr(true);
        return socketServer;
    }

    /**
     * 启动socket服务
     */
    public static boolean start() {
        try {
            getSocket().start();
        } catch (Exception e){
            return false;
        }
        log.info("socket 已启动");
        return true;
    }

    /**
     * 停止socket服务
     */
    public static boolean stop(){
        try {
            if(socketServer != null){
                socketServer.stop();
            }
        } catch (InterruptedException e) {
            return false;
        }
        return true;
    }

}
